# The Jac Programming Language and Jaseci Core

The next generation is upon us... (In ideation and specification phase)

Get to the docs, check the guidelines on how to contribute.

## Getting Docs Up Locally

Go to `/docs` base dir and run

```bash
yarn install
yarn start
```

For instructions on installing `yarn`, start on that journey with [their instructions](https://yarnpkg.com/getting-started/install).